Struct ZwpInputMethodManagerV2
pub struct ZwpInputMethodManagerV2 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
input method manager
The input method manager allows the client to become the input method on a chosen seat.
No more than one input method must be associated with any seat at any given time.
This interface has no events.
Implementations
impl ZwpInputMethodManagerV2
impl ZwpInputMethodManagerV2
pub fn get_input_method<U, D>(
&self,
seat: &WlSeat,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpInputMethodV2
pub fn get_input_method<U, D>( &self, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> ZwpInputMethodV2
request an input method object
Request a new input zwp_input_method_v2 object associated with a given seat.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the input method manager
Destroys the zwp_input_method_manager_v2 object.
The zwp_input_method_v2 objects originating from it remain valid.